@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * application.cc 
+ * application.cc
  *
  * Copyright (C) 2004-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -58,6 +58,7 @@
 #include <gcu/cmd-context.h>
 #include <gcu/loader.h>
 #include <gcu/loader-error.h>
+#include <gccv/canvas.h>
 #include <glib/gi18n-lib.h>
 #include <fstream>
 #include <cstring>
@@ -150,7 +151,7 @@ static void load_globs ()
       const char *end_ptr;
       char *dir;
       int len;
- 
+
       end_ptr = ptr;
       while (*end_ptr != ':' && *end_ptr != '\000')
 	end_ptr ++;
@@ -332,7 +333,7 @@ Application::Application (gcugtk::CmdContextGtk *cc):
 		/* Initialize plugins manager */
 		gcu::Loader::Init (this);
 /*		OBConversion Conv;
-		m_Have_InChI = Conv.FindFormat ("inchi") != NULL || 
+		m_Have_InChI = Conv.FindFormat ("inchi") != NULL ||
 			(g_spawn_command_line_sync ("which main_inchi", &result, &errors, NULL, NULL)
 			&& result && strlen (result));
 		if (result)
@@ -390,12 +391,14 @@ Application::Application (gcugtk::CmdContextGtk *cc):
 		OnDeleteSignal = Object::CreateNewSignalId ();
 		OnThemeChangedSignal = Object::CreateNewSignalId ();
 
+#if 0
 		/* get the theme style for labels so that tools buttons colors might
 		be adapted to the current theme */
 		GtkWidget *w = gtk_label_new ("");
-		m_Style = GTK_STYLE (g_object_ref (gtk_rc_get_style (w)));
+		GtkStyleContext *ctxt = gtk_widget_get_style_context (w);
 		g_object_ref_sink (w);
 		g_object_unref (w);
+#endif
 
 		// load settings before plugins
 		m_ConfNode = go_conf_get_node (GetConfDir (), GCP_CONF_DIR_SETTINGS);
@@ -410,7 +413,7 @@ Application::Application (gcugtk::CmdContextGtk *cc):
 		// load plugins
 		Plugin::LoadPlugins ();
 		m_bInit = true;
-		g_idle_add (reinterpret_cast <GSourceFunc> (ApplicationPrivate::Init), this); 
+		g_idle_add (reinterpret_cast <GSourceFunc> (ApplicationPrivate::Init), this);
 	}
 	RadioActions = NULL;
 	m_entries = 0;
@@ -457,7 +460,7 @@ Application::Application (gcugtk::CmdContextGtk *cc):
 				TestSupportedType (line);
 		}
 	}
-	
+
 	// make themes permanent with this as a dummy client
 	list <string> Names = TheThemeManager.GetThemesNames ();
 	list <string>::iterator j, jend = Names.end ();
@@ -496,7 +499,9 @@ Application::~Application ()
 	go_conf_free_node (m_ConfNode);
 	m_ConfNode = NULL;
 	TheThemeManager.Shutdown ();
+#if 0
 	g_object_unref (m_Style);
+#endif
 	// unref cursors
 	for (int i = 0; i < CursorMax; i++)
 		gdk_cursor_unref (m_Cursors[i]);
@@ -505,6 +510,10 @@ Application::~Application ()
 	g_object_unref (IconFactory);
 	// unload plugins
 	Plugin::UnloadPlugins ();
+	std::map < std::string, gccv::Canvas * >::iterator k, kend = m_ToolCanvases.end ();
+	for (k = m_ToolCanvases.begin (); k != kend; k++)
+		delete (*k).second;
+	m_ToolCanvases.clear ();
 }
 
 void Application::ActivateTool (const string& toolname, bool activate)
@@ -521,7 +530,7 @@ void Application::ActivateTool (const string& toolname, bool activate)
 					gtk_toggle_tool_button_set_active (button, true);
 				Tools *ToolsBox = dynamic_cast<Tools*> (GetDialog ("tools"));
 				if (ToolsBox)
-					ToolsBox->OnSelectTool (m_pActiveTool);		
+					ToolsBox->OnSelectTool (m_pActiveTool);
 			}
 		} else {
 			if (m_pActiveTool == m_Tools[toolname])
@@ -828,7 +837,7 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 			throw 1;
 		}
 		xmlKeepBlanksDefault (1); // to be sure we don't loose significant spaces.
-		if (!(xml = xmlReadIO ((xmlInputReadCallback) cb_vfs_to_xml, 
+		if (!(xml = xmlReadIO ((xmlInputReadCallback) cb_vfs_to_xml,
 				 (xmlInputCloseCallback) g_input_stream_close, input, filename.c_str (), NULL, 0))) {
 			g_object_unref (file);
 			throw 1;
@@ -932,7 +941,7 @@ void Application::Zoom (double zoom)
 	else {
 		Dialog *pDialog = GetDialog ("Zoom");
 		if (pDialog)
-			pDialog->Present (); 
+			pDialog->Present ();
 		else
 			new ZoomDlg (m_pActiveDoc);
 	}
@@ -964,7 +973,7 @@ void Application::OnToolChanged (GtkAction *current)
 	m_pActiveTool = m_Tools[gtk_action_get_name (current)];
 	Tools *ToolsBox = dynamic_cast<Tools*> (GetDialog ("tools"));
 	if (ToolsBox)
-		ToolsBox->OnSelectTool (m_pActiveTool);		
+		ToolsBox->OnSelectTool (m_pActiveTool);
 	if (m_pActiveTool)
 		m_pActiveTool->Activate(true);
 }
@@ -996,8 +1005,8 @@ void Application::BuildTools () throw (std::runtime_error)
 	m_pActiveTool = m_Tools["Select"];
 	if (m_pActiveTool)
 		m_pActiveTool->Activate(true);
-	ToolsBox->OnSelectTool (m_pActiveTool);	
-	ToolsBox->OnElementChanged (m_CurZ);	
+	ToolsBox->OnSelectTool (m_pActiveTool);
+	ToolsBox->OnElementChanged (m_CurZ);
 }
 
 void Application::ShowTools (bool visible)
@@ -1029,51 +1038,114 @@ void Application::AddActions (GtkRadioActionEntry const *entries, int nb, char c
 	if (ui_description)
 		UiDescs.push_back (ui_description);
 	if (icons) {
+		GtkCssProvider *provider = gtk_css_provider_get_default ();
+		GtkStyleContext *ctxt = gtk_style_context_new ();
+		GtkWidgetPath *path = gtk_widget_path_new ();
+		gtk_widget_path_append_type (path, GTK_TYPE_BUTTON);
+		gtk_style_context_set_path (ctxt, path);
+		gtk_widget_path_free (path);
+		gtk_style_context_add_provider (ctxt, GTK_STYLE_PROVIDER (provider), 1);
 		GtkIconSet *set;
 		GtkIconSource *src;
 		while (icons->name) {
-			GdkPixbuf *pixbuf = gdk_pixbuf_new_from_inline (-1, icons->data_24, false, NULL);
-			set = gtk_icon_set_new ();
-			src = gtk_icon_source_new ();
-			gtk_icon_source_set_size_wildcarded (src, true);
-			gtk_icon_source_set_state_wildcarded (src, false);
-			gtk_icon_source_set_direction_wildcarded (src, true);
+			GdkPixbuf *icon;
+			if (icons->data_24) {
+				GdkPixbuf *pixbuf = gdk_pixbuf_new_from_inline (-1, icons->data_24, false, NULL);
+				set = gtk_icon_set_new ();
+				src = gtk_icon_source_new ();
+				gtk_icon_source_set_size_wildcarded (src, true);
+				gtk_icon_source_set_state_wildcarded (src, false);
+				gtk_icon_source_set_direction_wildcarded (src, true);
 
-			for (int c = 0; c < 5; c++) {
-				GdkPixbuf *icon = gdk_pixbuf_copy (pixbuf);
-				// set the pixbuf color to the corresponding style for the style
-				unsigned char red, blue, green;
-				red = m_Style->fg[c].red >> 8;
-				green = m_Style->fg[c].green >> 8;
-				blue = m_Style->fg[c].blue >> 8;
-				unsigned char *line, *cur;
-				line = gdk_pixbuf_get_pixels (icon);
-				int i, j, rows, cols, rowstride;
-				cols = gdk_pixbuf_get_width (icon);
-				rows = gdk_pixbuf_get_height (icon);
-				rowstride = gdk_pixbuf_get_rowstride (icon);
-				for (i = 0; i < rows; i++) {
-					cur = line;
-					line += rowstride;
-					for (j = 0; j < cols; j++) {
-						cur[0] = cur[0] ^ red;
-						cur[1] = cur[1] ^ green;
-						cur[2] = cur[2] ^ blue;
-						cur += 4;
+				for (int c = 0; c < 5; c++) {
+				icon = gdk_pixbuf_copy (pixbuf);
+#if 0
+					// set the pixbuf color to the corresponding style for the style
+					unsigned char red, blue, green;
+					red = m_Style->fg[c].red >> 8;
+					green = m_Style->fg[c].green >> 8;
+					blue = m_Style->fg[c].blue >> 8;
+					unsigned char *line, *cur;
+					line = gdk_pixbuf_get_pixels (icon);
+					int i, j, rows, cols, rowstride;
+					cols = gdk_pixbuf_get_width (icon);
+					rows = gdk_pixbuf_get_height (icon);
+					rowstride = gdk_pixbuf_get_rowstride (icon);
+					for (i = 0; i < rows; i++) {
+						cur = line;
+						line += rowstride;
+						for (j = 0; j < cols; j++) {
+							cur[0] = cur[0] ^ red;
+							cur[1] = cur[1] ^ green;
+							cur[2] = cur[2] ^ blue;
+							cur += 4;
+						}
 					}
+#endif
+					gtk_icon_source_set_pixbuf (src, icon);
+					gtk_icon_source_set_state (src, static_cast <GtkStateType> (c));
+					gtk_icon_set_add_source (set, src);	/* copies the src */
+					g_object_unref (icon);
 				}
-				gtk_icon_source_set_pixbuf (src, icon);
-				gtk_icon_source_set_state (src, static_cast <GtkStateType> (c));
-				gtk_icon_set_add_source (set, src);	/* copies the src */
-				g_object_unref (icon);
+				gtk_icon_source_free (src);
+				gtk_icon_factory_add (IconFactory, icons->name, set);	/* keeps reference to set */
+				gtk_icon_set_unref (set);
+				g_object_unref (pixbuf);
+			} else if (icons->canvas) {
+				cairo_surface_t *surface;
+				cairo_t *cr;
+				set = gtk_icon_set_new ();
+				src = gtk_icon_source_new ();
+				gtk_icon_source_set_size_wildcarded (src, true);
+				gtk_icon_source_set_state_wildcarded (src, false);
+				gtk_icon_source_set_direction_wildcarded (src, true);
+				for (int c = 0; c < 7; c++) {
+					GtkStateFlags state;
+					switch (c) {
+					default:
+					case 0:
+						state = GTK_STATE_FLAG_NORMAL;
+						break;
+					case 1:
+						state = GTK_STATE_FLAG_ACTIVE;
+						break;
+					case 2:
+						state = GTK_STATE_FLAG_PRELIGHT;
+						break;
+					case 3:
+						state = GTK_STATE_FLAG_SELECTED;
+						break;
+					case 4:
+						state = GTK_STATE_FLAG_INSENSITIVE;
+						break;
+					case 5:
+						state = GTK_STATE_FLAG_INCONSISTENT;
+						break;
+					case 6:
+						state = GTK_STATE_FLAG_FOCUSED;
+						break;
+					}
+					GdkRGBA rgba;
+					gtk_style_context_get_color (ctxt, state, &rgba);
+					icon = gdk_pixbuf_new (GDK_COLORSPACE_RGB, true, 8, 24, 24);
+					surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, 24, 24);
+					cr = cairo_create (surface);
+					gtk_widget_set_state_flags (icons->canvas->GetWidget (), static_cast < GtkStateFlags > (c? 1 << (c - 1): 0), true);
+					icons->canvas->SetColor (GO_COLOR_FROM_GDK_RGBA (rgba));
+					icons->canvas->Render (cr, false);
+					go_cairo_convert_data_to_pixbuf (gdk_pixbuf_get_pixels (icon), cairo_image_surface_get_data (surface), 24, 24, 96);
+					gtk_icon_source_set_pixbuf (src, icon);
+					gtk_icon_source_set_state (src, static_cast <GtkStateType> (c));
+					gtk_icon_set_add_source (set, src);	/* copies the src */
+					g_object_unref (icon);
+				}
+				gtk_icon_source_free (src);
+				gtk_icon_factory_add (IconFactory, icons->name, set);	/* keeps reference to set */
+				gtk_icon_set_unref (set);
 			}
-		
-			gtk_icon_source_free (src);
-			gtk_icon_factory_add (IconFactory, icons->name, set);	/* keeps reference to set */
-			gtk_icon_set_unref (set);
-			g_object_unref (pixbuf);
 			icons++;
 		}
+		g_object_unref (ctxt);
 	}
 }
 
