@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemisty Utils
- * gcr/document.cc 
+ * gcr/document.cc
  *
  * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -25,7 +25,13 @@
 #include "config.h"
 #include <cstring>
 #include "document.h"
+#include "application.h"
 #include "view.h"
+#include "celldlg.h"
+#include "atomsdlg.h"
+#include "linesdlg.h"
+#include "sizedlg.h"
+#include "cleavagesdlg.h"
 #include <gcu/cylinder.h>
 #include <gcu/matrix.h>
 #include <gcu/objprops.h>
@@ -50,7 +56,7 @@
 using namespace std;
 
 namespace gcr {
-	
+
 gchar const *LatticeName[] = {
 	"simple cubic",
 	"body-centered cubic",
@@ -325,7 +331,7 @@ void Document::Update()
 			break;
 		}
 	}
-	
+
 	////////////////////////////////////////////////////////////
 	//Establish list of lines
 	LineList::iterator j, jend = LineDef.end();
@@ -405,6 +411,9 @@ void Document::Update()
 		std::vector<double>::iterator m;
 		unsigned n;
 
+		// we might have invalid cleavages, so we need to skip them
+		if ((*k)->Planes () == 0 || ((*k)->h () == 0 && (*k)->k () == 0 && (*k)->l () == 0))
+			continue;	// invalid cleavage
 		//scalar products calculus and storing
 		for (i = Atoms.begin(); i != Atoms.end(); i++)
 		{
@@ -437,7 +446,7 @@ void Document::Update()
 
 		ScalarProducts.clear() ;
 	}
-	
+
 	//Transform coordinates to Cartesians and find center of visible view
 	gdouble x, y, z, d,
 		xmin = G_MAXDOUBLE, ymin = G_MAXDOUBLE, zmin = G_MAXDOUBLE,
@@ -542,7 +551,7 @@ void Document::Duplicate (Line& line)
 		LineX.Move (1,0,0) ;
 	}
 }
-	
+
 void Document::Draw (gcu::Matrix const &m) const
 {
 	gcu::Vector v, v1;
@@ -610,9 +619,23 @@ xmlDocPtr Document::BuildXMLTree () const
 	xmlNodePtr node;
 	xmlNsPtr ns;
 
+	// first check if dialogs are open and data coherent
+	gcu::Dialog *dlg;
+	if ((dlg = GetDialog ("atoms"))) {
+		const_cast <Document * > (this)->CheckAtoms ();
+		static_cast < AtomsDlg * > (dlg)->ReloadData ();
+	}
+	if ((dlg = GetDialog ("cleavages"))) {
+		const_cast <Document * > (this)->CheckCleavages ();
+		static_cast < CleavagesDlg * > (dlg)->ReloadData ();
+	}
+	if ((dlg = GetDialog ("lines"))) {
+		const_cast <Document * > (this)->CheckLines ();
+		static_cast < LinesDlg * > (dlg)->ReloadData ();
+	}
 	xml = xmlNewDoc((xmlChar*)"1.0");
 	if (xml == NULL) {throw(1);}
-	
+
 	xmlDocSetRootElement (xml,  xmlNewDocNode(xml, NULL, (xmlChar*)"crystal", NULL));
 	ns = xmlNewNs (xml->children, (xmlChar*) "http://www.nongnu.org/gcrystal", (xmlChar*) "gcry");
 	xmlSetNs (xml->children, ns);
@@ -621,7 +644,7 @@ xmlDocPtr Document::BuildXMLTree () const
 	{
 		node = xmlNewDocNode(xml, NULL, (xmlChar*)"generator", (xmlChar*)GetProgramId());
 		if (node) xmlAddChild(xml->children, node); else throw (int) 0;
-		
+
 		node = xmlNewDocNode(xml, NULL, (xmlChar*)"lattice", (xmlChar*)LatticeName[m_lattice]);
 		if (node) xmlAddChild(xml->children, node); else throw (int) 0;
 		if (m_SpaceGroup) {
@@ -661,42 +684,42 @@ xmlDocPtr Document::BuildXMLTree () const
 		gcu::WriteFloat (node, "alpha", m_alpha);
 		gcu::WriteFloat (node, "beta", m_beta);
 		gcu::WriteFloat (node, "gamma", m_gamma);
-	
+
 		node = xmlNewDocNode(xml, NULL, (xmlChar*)"size", NULL);
 		if (node) xmlAddChild(xml->children, node); else throw (int) 0;
 		gcu::WritePosition(xml, node, "start", m_xmin, m_ymin, m_zmin);
 		gcu::WritePosition(xml, node, "end", m_xmax, m_ymax, m_zmax);
 		if (m_FixedSize)
 			xmlNewProp (node, (xmlChar *) "fixed", (xmlChar *) "true");
-		
+
 		AtomList::const_iterator i;
 		for (i = AtomDef.begin(); i != AtomDef.end(); i++)
 		{
 			node = (*i)->Save(xml);
 			if (node) xmlAddChild(xml->children, node); else throw (int) 0;
 		}
-	
+
 		LineList::const_iterator j;
 		for (j = LineDef.begin(); j != LineDef.end(); j++)
 		{
 			node = (*j)->Save(xml);
 			if (node) xmlAddChild(xml->children, node); else throw (int) 0;
 		}
-	
+
 		CleavageList::const_iterator k;
 		for (k = Cleavages.begin(); k != Cleavages.end(); k++)
 		{
 			node = (*k)->Save(xml);
 			if (node) xmlAddChild(xml->children, node); else throw (int) 0;
 		}
-		
+
 		list<View*>::const_iterator view;
 		for (view = m_Views.begin(); view != m_Views.end(); view++)
 		{
 			node = (*view)->Save(xml);
 			if (node) xmlAddChild(xml->children, node); else throw (int) 0;
 		}
-	
+
 		return xml;
 	}
 	catch (int num)
@@ -803,22 +826,22 @@ bool Document::SetProperty (unsigned property, char const *value)
 {
 	switch (property) {
 	case GCU_PROP_CELL_A:
-		m_a = strtod (value, NULL) * GetScale ();
+		m_a = g_ascii_strtod (value, NULL) * GetScale ();
 		break;
 	case GCU_PROP_CELL_B:
-		m_b = strtod (value, NULL) * GetScale ();
+		m_b = g_ascii_strtod (value, NULL) * GetScale ();
 		break;
 	case GCU_PROP_CELL_C:
-		m_c = strtod (value, NULL) * GetScale ();
+		m_c = g_ascii_strtod (value, NULL) * GetScale ();
 		break;
 	case GCU_PROP_CELL_ALPHA:
-		m_alpha = strtod (value, NULL);
+		m_alpha = g_ascii_strtod (value, NULL);
 		break;
 	case GCU_PROP_CELL_BETA:
-		m_beta = strtod (value, NULL);
+		m_beta = g_ascii_strtod (value, NULL);
 		break;
 	case GCU_PROP_CELL_GAMMA:
-		m_gamma = strtod (value, NULL);
+		m_gamma = g_ascii_strtod (value, NULL);
 		break;
 	case GCU_PROP_CHEMICAL_NAME_COMMON:
 		m_NameCommon = value;
@@ -1155,4 +1178,143 @@ void Document::SetCell (Lattice lattice, double a, double b, double c, double al
 	m_gamma = gamma;
 }
 
+static int gcd_euler (int n1, int n2)
+{
+	int buf;
+	if (n1 < n2) {
+		buf = n1;
+		n1 = n2;
+		n2 = buf;
+	}
+	while (1) {
+		if (n2 == 0)
+			return n1;
+		buf = n1 % n2;
+		n1 = n2;
+		n2 = buf;
+	}
+}
+
+void Document::CheckCleavages ()
+{
+	std::set < Cleavage * > garbage;
+	CleavageList::iterator i, j, end = Cleavages.end ();
+	int gcd;
+	for (i = Cleavages.begin (); i != end; i++) {
+		if ((*i)->Planes () == 0) {
+			garbage.insert (*i);
+			continue;
+		}
+		// now divide h, k, and l by their gcd, using Euclid's algorithm
+		// since we probably don't need better there
+		gcd = abs ((*i)->h ());
+		if (!gcd) {
+			gcd = abs ((*i)->k ());
+			if (!gcd) {
+				gcd = abs ((*i)->l ());
+				if (!gcd) {
+					garbage.insert (*i);
+					continue;
+				}
+			}
+		} else
+			gcd = gcd_euler (gcd, abs ((*i)->k ()));
+		gcd = gcd_euler (gcd, abs ((*i)->l ()));
+		(*i)->h () /= gcd;
+		(*i)->k () /= gcd;
+		(*i)->l () /= gcd;
+		// now we look for equivalent cleavages in the list beginning
+		for (j = Cleavages.begin (); j != i; j++)
+			if (*i == *j) {
+				if ((*j)->Planes () > (*i)->Planes ()) // use the largest planes number
+					(*i)->Planes () = (*j)->Planes ();
+				garbage.insert (*j);
+				break;
+			}
+	}
+	std::set < Cleavage * >::iterator k,kend = garbage.end ();
+	for (k = garbage.begin (); k != kend; k++) {
+		Cleavages.remove (*k);
+		delete *k;
+	}
+}
+
+void Document::CheckAtoms ()
+{
+	std::set < Atom * > garbage;
+	AtomList::iterator i, j, end = AtomDef.end ();
+	for (i = AtomDef.begin (); i != end; i++) {
+		for (j = AtomDef.begin (); j != i; j++)
+			if (*i == *j) {
+				garbage.insert (*j);
+				break;
+			}
+	}
+	std::set < Atom * >::iterator k,kend = garbage.end ();
+	for (k = garbage.begin (); k != kend; k++) {
+		AtomDef.remove (*k);
+		delete *k;
+	}
+}
+
+void Document::CheckLines ()
+{
+	std::set < Line * > garbage;
+	LineList::iterator i, j, end = LineDef.end ();
+	for (i = LineDef.begin (); i != end; i++) {
+		for (j = LineDef.begin (); j != i; j++)
+			if (*i == *j) {
+				garbage.insert (*j);
+				break;
+			}
+	}
+	std::set < Line * >::iterator k,kend = garbage.end ();
+	for (k = garbage.begin (); k != kend; k++) {
+		LineDef.remove (*k);
+		delete *k;
+	}
+}
+
+void Document::Define (unsigned nPage)
+{
+	gcu::Dialog *dialog;
+	switch (nPage) {
+	case 0:
+		dialog = GetDialog ("cell");
+		if (dialog)
+			dialog->Present ();
+		else
+			new gcr::CellDlg (static_cast < Application * > (m_App), this);
+		break;
+	case 1:
+		dialog = GetDialog ("atoms");
+		if (dialog)
+			dialog->Present ();
+		else
+			new gcr::AtomsDlg (static_cast <Application *> (m_App), this);
+		break;
+	case 2:
+		dialog = GetDialog ("lines");
+		if (dialog)
+			dialog->Present ();
+		else
+			new gcr::LinesDlg (static_cast <Application *> (m_App), this);
+		break;
+	case 3:
+		dialog = GetDialog ("size");
+		if (dialog)
+			dialog->Present ();
+		else
+			new gcr::SizeDlg (static_cast <Application *> (m_App), this);
+		break;
+	case 4:
+		dialog = GetDialog ("cleavages");
+		if (dialog)
+			dialog->Present ();
+		else
+			new gcr::CleavagesDlg (static_cast < Application * > (m_App), this);
+		break;
+	}
+}
+
 }	//	namespace gcr
