@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * docprop.cc 
+ * docprop.cc
  *
  * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -34,12 +34,14 @@ using namespace std;
 
 static void on_title_changed (GtkEntry *entry, gcDocPropDlg *dlg)
 {
-	dlg->OnTitleChanged (gtk_entry_get_text (entry));
+	char const *txt = gtk_entry_get_text (entry);
+	dlg->OnTitleChanged ((txt && *txt)? txt: NULL);
 }
 
 static bool on_title_focused_out (GtkEntry *entry, G_GNUC_UNUSED GdkEventFocus *event, gcDocPropDlg *dlg)
 {
-	dlg->OnTitleChanged (gtk_entry_get_text (entry));
+	char const *txt = gtk_entry_get_text (entry);
+	dlg->OnTitleChanged ((txt && *txt)? txt: NULL);
 	return false;
 }
 
@@ -120,7 +122,7 @@ gcDocPropDlg::gcDocPropDlg (gcDocument* pDoc):
 	g_signal_connect (G_OBJECT (Buffer), "changed", G_CALLBACK (on_comments_changed), this);
 	gtk_widget_show_all(GTK_WIDGET (dialog));
 }
-	
+
 gcDocPropDlg::~gcDocPropDlg ()
 {
 }
